#ifndef POKEPLATINUM_UNK_0200B358_H
#define POKEPLATINUM_UNK_0200B358_H

#include "struct_decls/struct_0200B358_decl.h"
#include "strbuf.h"
#include "struct_decls/struct_02025E6C_decl.h"
#include "struct_defs/box_pokemon.h"
#include "struct_decls/struct_020797DC_decl.h"
#include "struct_defs/trainer_data.h"
#include "struct_decls/struct_021C0794_decl.h"

#include "enums.h"

UnkStruct_0200B358 * sub_0200B358(u32 param0);
UnkStruct_0200B358 * sub_0200B368(u32 param0, u32 param1, u32 param2);
void sub_0200B3F0(UnkStruct_0200B358 * param0);
void sub_0200B48C(UnkStruct_0200B358 * param0, u32 param1, const Strbuf *param2, u32 param3, BOOL param4, u32 param5);
void sub_0200B498(UnkStruct_0200B358 * param0, u32 param1, const UnkStruct_02025E6C * param2);
void sub_0200B4BC(UnkStruct_0200B358 * param0, u32 param1, const UnkStruct_021C0794 * param2);
void sub_0200B4E4(UnkStruct_0200B358 * param0, u32 param1, const UnkStruct_021C0794 * param2);
void sub_0200B538(UnkStruct_0200B358 * param0, u32 param1, BoxPokemon * param2);
void sub_0200B578(UnkStruct_0200B358 * param0, u32 param1, BoxPokemon * param2);
void sub_0200B594(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200B5CC(UnkStruct_0200B358 * param0, u32 param1, BoxPokemon * param2);
void sub_0200B5EC(UnkStruct_0200B358 * param0, u32 param1, BoxPokemon * param2);
void sub_0200B60C(UnkStruct_0200B358 * param0, u32 param1, s32 param2, u32 param3, int param4, int param5);
void sub_0200B630(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200B668(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200B6A0(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200B6D8(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200B70C(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200B744(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200B77C(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200B7B4(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200B7EC(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200B824(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200B85C(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200B890(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200B8C8(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200B928(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200B960(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200B998(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200B9D0(UnkStruct_0200B358 * param0, u32 param1, TrainerData * param2);
void sub_0200BA08(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200BA40(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200BA74(UnkStruct_0200B358 * param0, u32 param1, TrainerData * param2);
void sub_0200BA94(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200BACC(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200BB04(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200BB3C(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200BB74(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200BBA8(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200BBDC(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200BC10(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200BC48(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200BC80(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200BCB8(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200BCF0(UnkStruct_0200B358 * param0, u32 param1, u8 param2);
void sub_0200BD40(UnkStruct_0200B358 * param0, u32 param1, const UnkStruct_020797DC * param2, u32 param3);
void sub_0200BD60(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200BD98(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200BDD0(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200BE08(UnkStruct_0200B358 * param0, u32 param1, u32 param2, u32 param3);
void sub_0200BE48(UnkStruct_0200B358 * param0, u32 param1, u16 param2);
void sub_0200BE64(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200BE98(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200BECC(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200BF74(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200BFAC(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200BFE4(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200C01C(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200C054(UnkStruct_0200B358 * param0, UnkStruct_021C0794 * param1, int param2, int param3, int param4);
void sub_0200C0B0(UnkStruct_0200B358 * param0, u32 param1, UnkEnum_ov66_022324D0 param2);
void sub_0200C0E8(UnkStruct_0200B358 * param0, u32 param1, int param2);
void sub_0200C120(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200C158(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200C190(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200C1C8(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200C200(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200C238(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200C270(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200C2A8(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200C2E0(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200C324(UnkStruct_0200B358 * param0, u32 param1);
void sub_0200C338(UnkStruct_0200B358 * param0, u32 param1, u32 param2);
void sub_0200C388(const UnkStruct_0200B358 * param0, Strbuf *param1, const Strbuf *param2);
void sub_0200C41C(UnkStruct_0200B358 * param0);

#endif // POKEPLATINUM_UNK_0200B358_H
